==> dimtim-utils-0.1.2.tar.gz: dimtim-utils-0.1.2/README.md <==
# dimtim-utils

Python utils for Dim-Tim projects

### Changelog

__v0.0.7__ _\[10.12.2021\]_

* Added `utils.text.inline(str)` function

-------------------------------------------------------------------------------

__v0.0.8__ _\[10.12.2021\]_

* Update `utils.debug.timeit(str?)` function

-------------------------------------------------------------------------------

__v0.0.9__ _\[17.01.2022\]_

* Added `utils.decorators.freezeargs()` decorator

-------------------------------------------------------------------------------

__v0.0.10__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.11__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.12__ _\[17.01.2022\]_

* Small json serializer fixes

-------------------------------------------------------------------------------

__v0.0.13__ _\[22.01.2022\]_

* Added `out` argument to `utils.debug.timeit(str?, Logger?)` to specify logger output
* Small fix in importing module
* Added `utils.text.to_kebab_case(str)` function
* Added some tests

-------------------------------------------------------------------------------

__v0.0.14__ _\[23.01.2022\]_

* Fix `helpers.management` import without installed __python-crontab__ library

-------------------------------------------------------------------------------

__v0.0.15__ _\[31.01.2022\]_

* Added `utils.terminal.show_progress(int, int, str?, IOBase?)` function

-------------------------------------------------------------------------------

__v0.0.16__ _\[31.01.2022\]_

* Fix `utils.terminal.show_progress(int, int, str?, IOBase?)` function

-------------------------------------------------------------------------------

__v0.0.17__ _\[26.05.2022\]_

* Fix `utils.json.JsonEncoder` datetime serialization
* Update requirements

-------------------------------------------------------------------------------

__v0.0.18__ _\[07.06.2022\]_

* Fix `utils.json.JsonEncoder` set and frozenset serialization

-------------------------------------------------------------------------------

__v0.1.0__ _\[14.06.2022\]_

* Added `helpers.management.runner.CommandRunner` class
* Added `dtrun` console command

-------------------------------------------------------------------------------

__v0.1.1__ _\[15.06.2022\]_

* Fixed `helpers.management.cron_command.CronCommand` cron tasks setup

-------------------------------------------------------------------------------

__v0.1.2__ _\[06.10.2022\]_

* Some fixes and update requirements

==> dimtim-utils-0.1.3.tar.gz: dimtim-utils-0.1.3/README.md <==
# dimtim-utils

Python utils for Dim-Tim projects

### Changelog

__v0.1.3__ _\[24.03.2023\]_

* `utils.timezone` package fixes
* Deprecation of `pytz` library in favor of `zoneinfo`

-------------------------------------------------------------------------------

__v0.1.2__ _\[06.10.2022\]_

* Some fixes and update requirements

-------------------------------------------------------------------------------

__v0.1.1__ _\[15.06.2022\]_

* Fixed `helpers.management.cron_command.CronCommand` cron tasks setup

-------------------------------------------------------------------------------

__v0.1.0__ _\[14.06.2022\]_

* Added `helpers.management.runner.CommandRunner` class
* Added `dtrun` console command

-------------------------------------------------------------------------------

__v0.0.18__ _\[07.06.2022\]_

* Fix `utils.json.JsonEncoder` set and frozenset serialization

-------------------------------------------------------------------------------

__v0.0.17__ _\[26.05.2022\]_

* Fix `utils.json.JsonEncoder` datetime serialization
* Update requirements

-------------------------------------------------------------------------------

__v0.0.16__ _\[31.01.2022\]_

* Fix `utils.terminal.show_progress(int, int, str?, IOBase?)` function

-------------------------------------------------------------------------------

__v0.0.15__ _\[31.01.2022\]_

* Added `utils.terminal.show_progress(int, int, str?, IOBase?)` function

-------------------------------------------------------------------------------

__v0.0.14__ _\[23.01.2022\]_

* Fix `helpers.management` import without installed __python-crontab__ library

-------------------------------------------------------------------------------

__v0.0.13__ _\[22.01.2022\]_

* Added `out` argument to `utils.debug.timeit(str?, Logger?)` to specify logger output
* Small fix in importing module
* Added `utils.text.to_kebab_case(str)` function
* Added some tests

-------------------------------------------------------------------------------

__v0.0.12__ _\[17.01.2022\]_

* Small json serializer fixes

-------------------------------------------------------------------------------

__v0.0.11__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.10__ _\[17.01.2022\]_

* Small fixes

-------------------------------------------------------------------------------

__v0.0.9__ _\[17.01.2022\]_

* Added `utils.decorators.freezeargs()` decorator

-------------------------------------------------------------------------------

__v0.0.8__ _\[10.12.2021\]_

* Update `utils.debug.timeit(str?)` function

-------------------------------------------------------------------------------

__v0.0.7__ _\[10.12.2021\]_

* Added `utils.text.inline(str)` function
